@@ -43,18 +43,9 @@ classicthemerestorerjso.ctr = {
 	} catch(e){}
 	
 	try{
-	  if (this.appversion >= 40) {
 		if(Services.prefs.getBranch("lightweightThemes.").getCharPref('selectedThemeID')=='firefox-devedition@mozilla.org') {
 		  this.fxdefaulttheme=false;
 		}
-		document.getElementById("ClassicTRoptionsPane").setAttribute('fx40plus',true);
-	  }
-	} catch(e){}
-	
-	try{
-	  if (this.appversion >= 44) {
-		document.getElementById("ClassicTRoptionsPane").setAttribute('fx44plus',true);
-	  }
 	} catch(e){}
 	
 	// restore last selected categories/tabs
@@ -136,7 +127,6 @@ classicthemerestorerjso.ctr = {
 		document.getElementById('ctraddon_pw_bookmarksbargroup2').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tabstoolbargroup').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_menubargroup2').style.visibility = 'collapse';
-		document.getElementById('ctraddon_pw_devthemegb').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_hightabpososx').style.visibility = 'collapse';
 		document.getElementById('ctraddon_altoptions_list').style.visibility = 'collapse';
 		document.getElementById('ctraddon_pw_tttitlebar').style.visibility = 'collapse';
@@ -150,12 +140,7 @@ classicthemerestorerjso.ctr = {
 		document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'collapse';
 		document.getElementById('ctraddon_altoptions_list2').style.visibility = 'collapse';
 	};
-	
-	//pref e10s tabs
-	document.getElementById('ctraddon_pw_e10stabs').disabled = true;
-	document.getElementById('ctraddon_pw_e10stabs').style.visibility = 'collapse';
-	document.getElementById('ctraddon_pw_e10stabsdescr').style.visibility = 'collapse';
-	
+
 	//ColorfulTabs info label
 	document.getElementById('ctraddon_coltabsinfo').style.visibility = 'collapse';
 
@@ -365,88 +350,13 @@ classicthemerestorerjso.ctr = {
 	if (this.prefs.getBoolPref('starinurl')) document.getElementById('ctraddon_pw_bmanimation').disabled = true;
 	
 	// hide settings, if unsupported by Firefox version
-	if (this.appversion < 31) {
-	  document.getElementById('ctraddon_pw_pananimation').style.visibility = 'collapse';
-	  
-	  document.getElementById('ctraddon_closetab_pw_act').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_closetab_pw_non').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_closetab_pw_sta').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_closetab_pw_end').style.visibility = 'collapse';
-	}
-	if (this.appversion < 32) {
-	  document.getElementById('ctraddon_pw_noconicons').style.visibility = 'collapse';
-	}
-	if (this.appversion < 33) {
-	  document.getElementById('ctraddon_experttweakstab').style.visibility = 'collapse';
-	}
-	if (this.appversion < 34) {
-	  document.getElementById('ctraddon_pw_oldsearchgb').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_loopcallgb').style.visibility = 'collapse';
-	}
-	if (this.appversion < 35) {
-	  document.getElementById('ctraddon_pw_devthemegb').style.visibility = 'collapse';
-	}
-	if (this.appversion < 36) {
-	  document.getElementById('ctraddon_pw_oldprefsgb').style.visibility = 'collapse';
-	}
-	if (this.appversion < 38) {
-	  document.getElementById('ctraddon_pw_readermodegb').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_pocketgb').style.visibility = 'collapse';
-	}
-	if (this.appversion < 40) {
-	  document.getElementById('ctraddon_pw_addonversion').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_alt_addonsm').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_am_compact').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_am_compact2').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_transpttbw10').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_altreaderico').style.visibility = 'collapse';
-	}
-	
-	if (this.appversion >= 40) {
-	  document.getElementById('ctraddon_pw_devthemegb').style.visibility = 'collapse';
-	}
-	
-	if (this.appversion >= 40 && this.appversion < 42) {
-	  document.getElementById('ctraddon_pw_nodevtheme2').style.visibility = 'collapse';
+	if (this.appversion < 46) {
+	  document.getElementById('ctraddon_pw_pocket2').style.visibility = 'collapse';
 	}
 
-	if (this.appversion < 41) {
-	  document.getElementById('ctraddon_pw_anewtaburlgbox').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_hideurlsrg').style.visibility = 'collapse';
-	}
-
-	if (this.appversion < 42) {
-	  document.getElementById('ctraddon_pw_fsaduration').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_tabsaudioicogb').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_ib_nohovcolor').style.visibility = 'collapse';
-	}
-
-	if (this.appversion >= 42) {
-	  document.getElementById('ctraddon_pw_readermode2').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_oldprefsgb').style.visibility = 'collapse';
-	}
-	
-	if (this.appversion < 43) {
-	  document.getElementById('ctraddon_pw_ctroldsearch').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_lbsugres').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_lbsugresbox').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_urlbar_uc').style.visibility = 'collapse';
-	}
-
-	if (this.appversion >= 43) {
-	  document.getElementById('ctraddon_pw_oldsearchgb').style.visibility = 'collapse';
-	}
-
-	if (this.appversion < 44) {
-	  document.getElementById('ctraddon_pw_altalertbox').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_urlbardropm2').style.visibility = 'collapse';
-	}
-
-	if (this.appversion < 45) {
-	  document.getElementById('ctraddon_pw_ibinfoico').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_ibinfoico2').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_iblabels').style.visibility = 'collapse';
-	  document.getElementById('ctraddon_pw_html5warning').style.visibility = 'collapse';
+	if (this.appversion >= 46) {
+	  document.getElementById('ctraddon_pw_pocket_descr').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_pocket').style.visibility = 'collapse';
 	}
 
 	if (this.appversion < 47) {
@@ -454,8 +364,25 @@ classicthemerestorerjso.ctr = {
 	  document.getElementById('ctraddon_pw_hideeditbm').style.visibility = 'collapse';
 	}
 	
+	if (this.appversion >= 47 && Services.appinfo.OS=="Darwin") {
+	  document.getElementById('ctraddon_pw_hidetbwote').style.visibility = 'collapse';
+	}
+	
 	if (this.appversion < 48) {
 	  document.getElementById('ctraddon_pw_altautocompl').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_autocompl_it').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_autocompl_rhl').style.visibility = 'collapse';
+	}
+
+	if (this.appversion >= 48) {
+	  document.getElementById('ctraddon_pw_urlbar_uc').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_urlbar_uc_desc').style.visibility = 'collapse';
+	}
+	
+	if (this.appversion < 50) {
+	  document.getElementById('ctraddon_pw_containertabgb').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_findbarhlgb').style.visibility = 'collapse';
+	  document.getElementById('ctraddon_pw_flywebgb').style.visibility = 'collapse';
 	}
 	
 	function PrefListener(branch_name, callback) {
@@ -559,12 +486,13 @@ classicthemerestorerjso.ctr = {
 	this.ctrpwNavBarPadding(this.prefs.getBoolPref("navbarpad"));
 	this.ctrpwLocationSearchbarSize(this.prefs.getBoolPref("lbsbsize"));
 	this.ctrpwLocationSearchbarRadius(this.prefs.getBoolPref("lbsbradius"));
-	this.ctrpwCompactAddonList(this.prefs.getBoolPref("am_compact"));
+	if (this.fxdefaulttheme) this.ctrpwCompactAddonList(this.prefs.getBoolPref("am_compact"));
 	this.ctrpwUnsortBM(this.prefs.getBoolPref("bmbunsortbm"));
 	this.ctrpwHideUrlStopRel(this.prefs.getBoolPref("hideurelstop"));
 	this.ctrpwExtraUrlbar(this.prefs.getBoolPref("extraurlkeycb"));
 	this.ctrpwSearchPopupSize(this.prefs.getBoolPref("osearch_cwidth"));
 	this.ctrpwAeroColors(this.prefs.getBoolPref("aerocolors"));
+	this.ctrpwAutoCompleteHeight(this.prefs.getBoolPref("urlresults"));
 	
 	var closetab_value = this.prefs.getCharPref("closetab");
   
@@ -648,30 +576,17 @@ classicthemerestorerjso.ctr = {
  
   hideThemeInfoForTabs: function(){
 	setTimeout(function(){
-		//try {
-		  if(classicthemerestorerjso.ctr.appversion < 41) {
-			try {
-			  if(Services.prefs.getBranch("browser.devedition.theme.").getBoolPref('enabled')!=false){
-				document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'visible';
-				document.getElementById('ctraddon_pw_tabmenulist').disabled = true;
-			  } else if(classicthemerestorerjso.ctr.fxdefaulttheme) {
-				document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'collapse';
-				document.getElementById('ctraddon_pw_tabmenulist').disabled = false;
-			  }
-			} catch(e) {}
-		  } else {
-			  try {
-				if(Services.prefs.getBranch("lightweightThemes.").getCharPref('selectedThemeID')=='firefox-devedition@mozilla.org'){
-				  document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'visible';
-				  document.getElementById('ctraddon_pw_tabmenulist').disabled = true;
-				} else if(classicthemerestorerjso.ctr.fxdefaulttheme) {
-				  document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'collapse';
-				  document.getElementById('ctraddon_pw_tabmenulist').disabled = false;
-				}
-			  } catch(e) {}
-			  
-		  }
-		//} catch(e) {}
+
+	  try {
+		if(Services.prefs.getBranch("lightweightThemes.").getCharPref('selectedThemeID')=='firefox-devedition@mozilla.org'){
+		  document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'visible';
+		  document.getElementById('ctraddon_pw_tabmenulist').disabled = true;
+		} else if(classicthemerestorerjso.ctr.fxdefaulttheme) {
+		  document.getElementById('ctraddon_pw_tabforminfo').style.visibility = 'collapse';
+		  document.getElementById('ctraddon_pw_tabmenulist').disabled = false;
+		}
+	  } catch(e) {}
+
 	},100);
   },
 
@@ -742,9 +657,13 @@ classicthemerestorerjso.ctr = {
 	  which=true; itemvis = 'collapse';
 	}
 	
-    document.getElementById('ctraddon_pw_hidetbwote').disabled = which;
+    if (this.appversion >= 47 && Services.appinfo.OS=="Darwin") {}
+	else {
+	  document.getElementById('ctraddon_pw_hidetbwote').disabled = which;
+	  document.getElementById('ctraddon_pw_hidetbwote').style.visibility = itemvis;
+	}
+	
 	document.getElementById('ctraddon_pw_hidetbwote2').disabled = which;
-	document.getElementById('ctraddon_pw_hidetbwote').style.visibility = itemvis;
 	document.getElementById('ctraddon_pw_hidetbwote_winc').style.visibility = itemvis;
 	document.getElementById('ctraddon_pw_hidetbwote2').style.visibility = itemvis;
   },
@@ -890,6 +809,18 @@ classicthemerestorerjso.ctr = {
     document.getElementById('ctraddon_pw_aerocolorsg').disabled = which;
 	document.getElementById('ctraddon_pw_aerocolorsg').style.visibility = itemvis;
   },
+  
+  ctrpwAutoCompleteHeight: function(which) {
+	var itemvis = 'collapse';
+	
+    if(which==true) {
+	  which=false; itemvis = 'visible';
+	} else {
+	  which=true; itemvis = 'collapse';
+	}
+	
+    document.getElementById('ctraddon_pw_autocompl_it').disabled = which;
+  },
  
   ctrpwCtrOldSearch: function(which) {
 	var itemvis = 'collapse';
@@ -1179,19 +1110,15 @@ classicthemerestorerjso.ctr = {
 	this.prefs.setBoolPref("activndicat",true);
 	this.prefs.setBoolPref("tbconmenu",true);
 
-	if(this.appversion >= 38) { 
-	  this.prefs.setCharPref("altoptions",'options_win_alt');
-	}
-	if(this.appversion >= 40) { 
-	  this.prefs.setBoolPref("alt_addonsm",true);
-	  this.prefs.setBoolPref("addonversion",true);
-	}
-	if(this.appversion >= 41) { 
-	  this.prefs.setBoolPref("hideurlsrg",true);
-	}
-	if(this.appversion >= 43) { 
-	  this.prefs.setBoolPref("oldsearch",true);
-	}
+	this.prefs.setCharPref("altoptions",'options_win_alt');
+
+	this.prefs.setBoolPref("alt_addonsm",true);
+	this.prefs.setBoolPref("addonversion",true);
+
+	this.prefs.setBoolPref("hideurlsrg",true);
+
+	this.prefs.setBoolPref("oldsearch",true);
+
 	if(this.appversion >= 48)
 	  this.prefs.setBoolPref("altautocompl",true);
 	
